@@ -171,7 +171,7 @@ struct Opt {
 
     #[structopt(
         long = "accept-from-fd",
-        help = "[A] Do not call `socket(2)` in UNIX socket listerer peer, start with `accept(2)` using specified file descriptor number as argument instead of filename"
+        help = "[A] Do not call `socket(2)` in UNIX socket listener peer, start with `accept(2)` using specified file descriptor number as argument instead of filename"
     )]
     unix_socket_accept_from_fd: bool,
 
@@ -343,6 +343,12 @@ struct Opt {
     )]
     process_exit_sighup: bool,
 
+    #[structopt(
+        long = "exec-exit-on-disconnect",
+        help = "[A] Make exec: or sh-c: or cmd: immediately exit when connection is closed, don't wait for termination."
+    )]
+    process_exit_on_disconnect: bool,
+
     #[structopt(
         long = "jsonrpc",
         help = "Format messages you type as JSON RPC 2.0 method calls. First word becomes method name, the rest becomes parameters, possibly automatically wrapped in []."
@@ -594,6 +600,62 @@ struct Opt {
     /// [A] Uncompress data coming from a WebSocket using deflate method. Affects only binary WebSocket messages.
     #[structopt(long = "uncompress-gzip")]
     pub uncompress_gzip: bool,
+
+    /// [A] Load specified symbol from specified native library and use it for `native_plugin_transform_a`.
+    /// Format is `symbol@library_file`. If `symbol@` is omitted, `websocat_transform` is implied.
+    #[cfg(feature = "native_plugins")]
+    #[structopt(long = "native-plugin-a",  parse(try_from_str = "websocat::transform_peer::load_symbol"))]
+    pub native_transform_a: Option<websocat::transform_peer::Sym>,
+
+    /// [A] Load specified symbol from specified native library and use it for `native_plugin_transform_b`.
+    #[cfg(feature = "native_plugins")]
+    #[structopt(long = "native-plugin-b", parse(try_from_str = "websocat::transform_peer::load_symbol"))]
+    pub native_transform_b: Option<websocat::transform_peer::Sym>,
+
+    /// [A] Load specified symbol from specified native library and use it for `native_plugin_transform_c`.
+    #[cfg(feature = "native_plugins")]
+    #[structopt(long = "native-plugin-c", parse(try_from_str = "websocat::transform_peer::load_symbol"))]
+    pub native_transform_c: Option<websocat::transform_peer::Sym>,
+
+    /// [A] Load specified symbol from specified native library and use it for `native_plugin_transform_d`.
+    #[cfg(feature = "native_plugins")]
+    #[structopt(long = "native-plugin-d", parse(try_from_str = "websocat::transform_peer::load_symbol"))]
+    pub native_transform_d: Option<websocat::transform_peer::Sym>,
+
+    /// [A] Load specified symbol from specified wasm module and use it for `wasm_plugin_transform_a:`.
+    /// Format is `symbol@library_file`. If `symbol@` is omitted, `websocat_transform` is implied.
+    /// The wasm module should also have `malloc` and `free` functions exposed.
+    /// Prepend `library_file` with `!` to load serialized cwasm produced by `wasmtime compile` instead of compining the module in Websocat.
+    #[cfg(feature = "wasm_plugins")]
+    #[structopt(long = "wasm-plugin-a",  parse(try_from_str = "websocat::wasm_transform_peer::load_symbol"))]
+    pub wasm_transform_a: Option<websocat::wasm_transform_peer::Handle>,
+
+    /// [A] Load specified symbol from specified wasm module and use it for `wasm_plugin_transform_b:`.
+    #[cfg(feature = "wasm_plugins")]
+    #[structopt(long = "wasm-plugin-b",  parse(try_from_str = "websocat::wasm_transform_peer::load_symbol"))]
+    pub wasm_transform_b: Option<websocat::wasm_transform_peer::Handle>,
+
+    /// [A] Load specified symbol from specified wasm module and use it for `wasm_plugin_transform_c:`.
+    #[cfg(feature = "wasm_plugins")]
+    #[structopt(long = "wasm-plugin-c",  parse(try_from_str = "websocat::wasm_transform_peer::load_symbol"))]
+    pub wasm_transform_c: Option<websocat::wasm_transform_peer::Handle>,
+
+    /// [A] Load specified symbol from specified wasm module and use it for `wasm_plugin_transform_d:`.
+    #[cfg(feature = "wasm_plugins")]
+    #[structopt(long = "wasm-plugin-d",  parse(try_from_str = "websocat::wasm_transform_peer::load_symbol"))]
+    pub wasm_transform_d: Option<websocat::wasm_transform_peer::Handle>,
+
+    /// [A] Omit `jsonrpc` field when using `--jsonrpc`, e.g. for Chromium
+    #[structopt(long = "jsonrpc-omit-jsonrpc")]
+    pub jsonrpc_omit_jsonrpc: bool,
+
+    /// [A] Stop replying to incoming WebSocket pings after specified number of replies 
+    #[structopt(long = "inhibit-pongs")]
+    pub inhibit_pongs: Option<usize>,
+
+    /// [A] Stop sending pings after this number of sent pings
+    #[structopt(long = "max-sent-pings")]
+    pub max_sent_pings: Option<usize>,
 }
 
 // TODO: make it byte-oriented/OsStr?
@@ -723,6 +785,11 @@ fn run() -> Result<()> {
         help::shorthelp();
         return Ok(());
     }
+    let mut logging_already_set = false;
+    if std::env::var("WEBSOCAT_EARLY_LOG").is_ok() {
+        logging::setup_env_logger(0)?;
+        logging_already_set = true;
+    }
 
     let mut cmd = Opt::from_args();
 
@@ -833,6 +900,7 @@ fn run() -> Result<()> {
             reuser_send_zero_msg_on_disconnect
             process_zero_sighup
             process_exit_sighup
+            process_exit_on_disconnect
             socks_destination
             auto_socks5
             socks5_bind_script
@@ -870,6 +938,9 @@ fn run() -> Result<()> {
             uncompress_deflate
             uncompress_zlib
             uncompress_gzip
+            jsonrpc_omit_jsonrpc
+            inhibit_pongs
+            max_sent_pings
         );
         #[cfg(feature = "ssl")]
         {
@@ -894,6 +965,24 @@ fn run() -> Result<()> {
                 prometheus
             }
         }
+        #[cfg(feature = "native_plugins")]
+        {
+            opts! {
+                native_transform_a
+                native_transform_b
+                native_transform_c
+                native_transform_d
+            }
+        }
+        #[cfg(feature = "wasm_plugins")]
+        {
+            opts! {
+                 wasm_transform_a
+                 wasm_transform_b
+                 wasm_transform_c
+                 wasm_transform_d
+            }
+        }
     };
 
     if let Some(ba) = cmd.basic_auth {
@@ -996,7 +1085,7 @@ fn run() -> Result<()> {
     if !quiet && recommend_explicit_text_or_bin {
         eprintln!("websocat: It is recommended to either set --binary or --text explicitly");
     }
-    if !quiet {
+    if !quiet && !logging_already_set {
         logging::setup_env_logger(cmd.verbosity)?;
     }
 
